==> hoteldruid-mod-sv_2.2.3-1.tar.gz: sv/storia_soldi.php <==
<?php

switch ($messaggio) {

case "Vedi le modifiche":  			$messaggio = "Se f&ouml;r&auml;ndringarna"; break;
case "dal":  					$messaggio = "fr&aring;n"; break;
case "al":  					$messaggio = "till"; break;
case "Senza colori":  				$messaggio = "Utan f&auml;rger"; break;
case "Con colori":  				$messaggio = "Med f&auml;rger"; break;
case "fino al":  				$messaggio = "till"; break;
case "Storia delle entate e uscite delle prenotazioni inserite nel":	$messaggio = "Betalningshistorik f&ouml;r bokningar infogade under"; break;
case "Dati della prenotazione":  		$messaggio = "Bokningsdata"; break;
case "Pagato prima":  				$messaggio = "Betalad f&ouml;re"; break;
case "Pagato dopo":  				$messaggio = "Betalad efter"; break;
case "Saldo":  					$messaggio = "Skillnad"; break;
case "Data_della modifica":  			$messaggio = "&Auml;ndringsdatum"; break;
case "Cognome_cliente":  			$messaggio = "Kund_efternamn"; break;
case "Data_iniziale":  				$messaggio = "Startdatum"; break;
case "Data_finale":  				$messaggio = "Slutdatum"; break;
case "TOTALE":  				$messaggio = "TOTALT"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Trasferito in cassa":  			$messaggio = "&Ouml;verf&ouml;rt till kassal&aring;da"; break;
case "RESTO":  					$messaggio = "&Aring;TERST&Aring;R"; break;
case "pagine":  				$messaggio = "sidor"; break;
case "Cliente":  				$messaggio = "Kund"; break;
case "Utente":  				$messaggio = "Anv&auml;ndare"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>azzerare</b></div> tutte le entrate e le uscite delle prenotazioni e i soldi trasferiti in cassa del":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill <div style=\"display: inline; color: red;\"><b>ta bort</b></div> alla bokningsbetalningar och penga&ouml;verf&ouml;ringar till kassal&aring;dan f&ouml;r"; break;
case "SI":  					$messaggio = "JA"; break;
case "NO":  					$messaggio = "NEJ"; break;
case "Azzera entrate e uscite prenotazioni":  	$messaggio = "Ta bort alla bokningsbetalningar"; break;
case "Metodo":  				$messaggio = "Metod"; break;
case "Vedi solo le entrate-uscite":  		$messaggio = "Se endast betalningar"; break;
case "con metodo":  				$messaggio = "med metod"; break;
case "N°":  					$messaggio = "N."; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-sv_3.0.8-1.tar.gz: sv/storia_soldi.php <==
<?php

switch ($messaggio) {

case "Vedi le modifiche":  			$messaggio = "Se f&ouml;r&auml;ndringarna"; break;
case "dal":  					$messaggio = "fr&aring;n"; break;
case "al":  					$messaggio = "till"; break;
case "Senza colori":  				$messaggio = "Utan f&auml;rger"; break;
case "Con colori":  				$messaggio = "Med f&auml;rger"; break;
case "fino al":  				$messaggio = "till"; break;
case "Storia delle entate e uscite delle prenotazioni inserite nel":	$messaggio = "Betalningshistorik f&ouml;r bokningar infogade under"; break;
case "Dati della prenotazione":  		$messaggio = "Bokningsdata"; break;
case "Pagato prima":  				$messaggio = "Betalad f&ouml;re"; break;
case "Pagato dopo":  				$messaggio = "Betalad efter"; break;
case "Saldo":  					$messaggio = "Skillnad"; break;
case "Data_della modifica":  			$messaggio = "&Auml;ndringsdatum"; break;
case "Cognome_cliente":  			$messaggio = "Kund_efternamn"; break;
case "Data_iniziale":  				$messaggio = "Startdatum"; break;
case "Data_finale":  				$messaggio = "Slutdatum"; break;
case "TOTALE":  				$messaggio = "TOTALT"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Trasferito in cassa":  			$messaggio = "&Ouml;verf&ouml;rt till kassal&aring;da"; break;
case "RESTO":  					$messaggio = "&Aring;TERST&Aring;R"; break;
case "pagine":  				$messaggio = "sidor"; break;
case "Cliente":  				$messaggio = "Kund"; break;
case "Utente":  				$messaggio = "Anv&auml;ndare"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\"><b>azzerare</b></div> tutte le entrate e le uscite delle prenotazioni e i soldi trasferiti in cassa del":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill <div style=\"display: inline; color: red;\"><b>ta bort</b></div> alla bokningsbetalningar och penga&ouml;verf&ouml;ringar till kassal&aring;dan f&ouml;r"; break;
case "SI":  					$messaggio = "JA"; break;
case "NO":  					$messaggio = "NEJ"; break;
case "Azzera entrate e uscite prenotazioni":  	$messaggio = "Ta bort alla bokningsbetalningar"; break;
case "Metodo":  				$messaggio = "Metod"; break;
case "Vedi solo le entrate-uscite":  		$messaggio = "Se endast betalningar"; break;
case "con metodo":  				$messaggio = "med metod"; break;
case "N°":  					$messaggio = "N."; break;
case "Id":  					$messaggio = "Id"; break;
case "Storico Entrate":  			$messaggio = "Payments History"; break;
case "Note":  					$messaggio = "Notes"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
